@@ -1,6 +1,6 @@
 /*
 
-  $Id: winserial.c,v 1.13 2005/04/20 20:37:41 pkot Exp $
+  $Id: winserial.c,v 1.16 2008/01/09 13:09:47 ladis Exp $
 
   G N O K I I
 
@@ -22,12 +22,14 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999-2000  Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000  Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2002       Ladis Michl
   Copyright (C) 2002-2004  BORBELY Zoltan, Pawel Kot
 
 */
 
+#include "config.h"
+
 #include <windows.h>
 #include <string.h>
 #include <stdio.h>
@@ -36,7 +38,7 @@
 
 #include "misc.h"
 #include "gnokii.h"
-#include "devices/winserial.h"
+#include "devices/serial.h"
 
 #define USECOMM      /* yes, we need the COMM API */
 
@@ -131,7 +133,7 @@ int serial_opendevice(const char *file, int with_odd_parity,
 		dcb.fRtsControl = RTS_CONTROL_ENABLE;
 	}
 	if (!SetCommState(hPhone, &dcb)) {
-		fprintf(stderr, "Gnokii serial_opendevice: cannot set handshake\n");
+		fprintf(stderr, _("Gnokii serial_opendevice: cannot set handshake\n"));
 		serial_close(0, state);
 		return -1;
 	}
@@ -221,7 +223,7 @@ size_t serial_read(int fd, __ptr_t buf, size_t nbytes, struct gn_statemachine *s
 				     dwLength, &dwLength, &osRead);
 		if (!fReadStat) {
 			if (GetLastError() == ERROR_IO_PENDING) {
-				fprintf(stderr, "\n\rIO Pending");
+				fprintf(stderr, _("\n\rIO Pending"));
 				/* We have to wait for read to complete.
 				 * This function will timeout according to the
 				 * CommTimeOuts.ReadTotalTimeoutConstant variable
@@ -299,9 +301,9 @@ size_t serial_write(int fd, __ptr_t buf, size_t n, struct gn_statemachine *state
 			dwBytesSent += dwBytesWritten;
 #if 0
 			if (dwBytesSent != dwBytesToWrite)
-				fprintf(stderr, "\nProbable Write Timeout: Total of %ld bytes sent (%ld)", dwBytesSent, dwBytesToWrite);
+				fprintf(stderr, _("\nProbable Write Timeout: Total of %ld bytes sent (%ld)"), dwBytesSent, dwBytesToWrite);
 			else
-				fprintf(stderr, "\n%ld bytes written", dwBytesSent);
+				fprintf(stderr, _("\n%ld bytes written"), dwBytesSent);
 #endif
 		} else {
 			/* some other error occurred */
