@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-call.c,v 1.17 2007/11/07 18:28:18 pkot Exp $
+  $Id: gsm-call.c,v 1.19 2008/02/03 13:28:23 pkot Exp $
 
   G N O K I I
 
@@ -29,6 +29,8 @@
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 
 #include "gnokii-internal.h"
@@ -54,7 +56,8 @@ GNOKII_API void gn_call_notifier(gn_call_status call_status, gn_call_info *call_
 
 	switch (call_status) {
 	case GN_CALL_Incoming:
-		if (call != NULL) break;
+		if (call != NULL)
+			break;
 		if ((call = search_call(0, NULL)) == NULL) {
 			dprintf("Call table overflow!\n");
 			break;
@@ -72,7 +75,8 @@ GNOKII_API void gn_call_notifier(gn_call_status call_status, gn_call_info *call_
 
 	case GN_CALL_LocalHangup:
 	case GN_CALL_RemoteHangup:
-		if (call == NULL) break;
+		if (call == NULL)
+			break;
 		memset(call, 0, sizeof(*call));
 		call->status = GN_CALL_Idle;
 		break;
@@ -97,12 +101,14 @@ GNOKII_API void gn_call_notifier(gn_call_status call_status, gn_call_info *call_
 		break;
 
 	case GN_CALL_Resumed:
-		if (call == NULL) break;
+		if (call == NULL)
+			break;
 		call->status = GN_CALL_Established;
 		break;
 
 	case GN_CALL_Held:
-		if (call == NULL) break;
+		if (call == NULL)
+			break;
 		call->status = GN_CALL_Held;
 		break;
 
@@ -146,7 +152,8 @@ GNOKII_API gn_error gn_call_answer(int call_id)
 	gn_data data;
 	gn_call_info call_info;
 
-	if (calltable[call_id].status == GN_CALL_Idle) return GN_ERR_NONE;
+	if (calltable[call_id].status == GN_CALL_Idle)
+		return GN_ERR_NONE;
 
 	memset(&call_info, 0, sizeof(call_info));
 	call_info.call_id = calltable[call_id].call_id;
@@ -161,7 +168,8 @@ GNOKII_API gn_error gn_call_cancel(int call_id)
 	gn_data data;
 	gn_call_info call_info;
 
-	if (calltable[call_id].status == GN_CALL_Idle) return GN_ERR_NONE;
+	if (calltable[call_id].status == GN_CALL_Idle)
+		return GN_ERR_NONE;
 
 	memset(&call_info, 0, sizeof(call_info));
 	call_info.call_id = calltable[call_id].call_id;
@@ -173,7 +181,8 @@ GNOKII_API gn_error gn_call_cancel(int call_id)
 
 GNOKII_API gn_call *gn_call_get_active(int call_id)
 {
-	if (calltable[call_id].status == GN_CALL_Idle) return NULL;
+	if (calltable[call_id].status == GN_CALL_Idle)
+		return NULL;
 
 	return calltable + call_id;
 }
@@ -190,12 +199,17 @@ GNOKII_API gn_error gn_call_check_active(struct gn_statemachine *state)
 	gn_data_clear(&data);
 	data.call_active = active;
 
+	/* initialize active call table */
+	for (i = 0; i < GN_CALL_MAX_PARALLEL; i++)
+		active[i].state = GN_CALL_Idle;
+
 	if ((err = gn_sm_functions(GN_OP_GetActiveCalls, &data, state)) != GN_ERR_NONE)
 		return (err == GN_ERR_NOTIMPLEMENTED || err == GN_ERR_NOTSUPPORTED) ? GN_ERR_NONE : err;
 
 	/* delete terminated calls */
 	for (j = 0; j < GN_CALL_MAX_PARALLEL; j++) {
-		if (calltable[j].state != state) continue;
+		if (calltable[j].state != state)
+			continue;
 		got = 0;
 		for (i = 0; i < GN_CALL_MAX_PARALLEL; i++) {
 			if (calltable[j].call_id == active[i].call_id) {
@@ -210,8 +224,10 @@ GNOKII_API gn_error gn_call_check_active(struct gn_statemachine *state)
 	}
 
 	for (i = 0; i < GN_CALL_MAX_PARALLEL; i++) {
-		if (active[i].state == GN_CALL_Idle) continue;
+		if (active[i].state == GN_CALL_Idle)
+			continue;
 
+		dprintf("call state: %d\n", active[i].state);
 		if (!(call = search_call(active[i].call_id, state))) {
 			/* incoming call */
 			if (active[i].state == GN_CALL_RemoteHangup || active[i].state == GN_CALL_LocalHangup)
