@@ -1,6 +1,6 @@
 /*
 
-  $Id: fbus.c,v 1.73 2007/11/22 17:30:20 pkot Exp $
+  $Id: fbus.c,v 1.75 2007/12/16 16:04:04 pkot Exp $
 
   G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2000      Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 2000      Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2000-2001 Chris Kemp
   Copyright (C) 2001-2006 Pawel Kot
   Copyright (C) 2001      Manfred Jonsson, Pavel Machek
@@ -37,6 +37,8 @@
 
 */
 
+#include "config.h"
+
 /* System header files */
 
 #include <stdio.h>
@@ -45,7 +47,6 @@
 
 /* Various header file */
 
-#include "config.h"
 #include "compat.h"
 #include "misc.h"
 #include "gnokii.h"
@@ -588,6 +589,14 @@ static gn_error fbus_send_message(unsigned int messagesize, unsigned char messag
 	seqnum = 0x40 + FBUSINST(state)->request_sequence_number;
 	FBUSINST(state)->request_sequence_number =
 	    (FBUSINST(state)->request_sequence_number + 1) & 0x07;
+	/*
+	 * For the very first time sequence number should be ORed with
+	 * 0x20. It should initialize sequence counter in the phone.
+	 */
+	if (FBUSINST(state)->init_frame) {
+		seqnum |= 0x20;
+		FBUSINST(state)->init_frame = 0;
+	}
 
 	if (messagesize > FBUS_CONTENT_MAX_LENGTH) {
 
@@ -678,6 +687,7 @@ gn_error fbus_initialise(int attempt, struct gn_statemachine *state)
 		return GN_ERR_MEMORYFULL;
 
 	FBUSINST(state)->request_sequence_number = 0;
+	FBUSINST(state)->init_frame = 1;
 
 	switch (state->config.connection_type) {
 	case GN_CT_Infrared:
