@@ -1,6 +1,6 @@
 /*
 
-  $Id: atsoer.c,v 1.17 2008/03/21 12:42:03 dforsi Exp $
+  $Id: atsoer.c,v 1.22 2008/05/30 17:17:25 pkot Exp $
 
   G N O K I I
 
@@ -23,9 +23,9 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright 2004 Hugo Haas <hugo@larve.net>
-  Copyright 2004 Pawel Kot
+  Copyright 2004-2008 Pawel Kot
 
-  This file provides functions specific to at commands on ericsson
+  This file provides functions specific to AT commands on Sony Ericsson
   phones. See README for more details on supported mobile phones.
 
 */
@@ -77,6 +77,11 @@ static gn_error se_at_memory_type_set(gn_memory_type mt, struct gn_statemachine
 	return ret;
 }
 
+/*
+ * Calculate phonebook size for SonyEricsson phones: they don't respond
+ * with memory stats to AT+CPBS. Calculate by reading and counting all
+ * entries (which is fast -- just one command).
+ */
 static gn_error ReplyMemoryStatus(int messagetype, unsigned char *buffer, int length, gn_data *data, struct gn_statemachine *state)
 {
 	at_driver_instance *drvinst = AT_DRVINST(state);
@@ -103,7 +108,11 @@ static gn_error ReplyMemoryStatus(int messagetype, unsigned char *buffer, int le
 	return error;
 }
 
-
+/*
+ * Calculate phonebook size for SonyEricsson phones: they don't respond
+ * with memory stats to AT+CPBS. Calculate by reading and counting all
+ * entries (which is fast -- just one command).
+ */
 static gn_error AT_GetMemoryStatus(gn_data *data, struct gn_statemachine *state)
 {
 	at_driver_instance *drvinst = AT_DRVINST(state);
@@ -124,27 +133,19 @@ static gn_error AT_GetMemoryStatus(gn_data *data, struct gn_statemachine *state)
 	return sm_block_no_retry(GN_OP_GetMemoryStatus, data, state);
 }
 
-static gn_error AT_GetNetworkInfo(gn_data *data, struct gn_statemachine *state)
-{
-	if (!data->network_info)
-		return GN_ERR_INTERNALERROR;
-
-	/* Sony Ericsson phones can't do CREG=2 (only CREG=1), so just
-	 * skip that and only do COPS */
-
-	if (sm_message_send(9, GN_OP_GetNetworkInfo, "AT+COPS?\r", state))
-		return GN_ERR_NOTREADY;
-	return sm_block_no_retry(GN_OP_GetNetworkInfo, data, state);
-}
-
-
 void at_sonyericsson_init(char* foundmodel, char* setupmodel, struct gn_statemachine *state)
 {
 	/* Sony Ericssons support just mode 2 */
 	AT_DRVINST(state)->cnmi_mode = 2;
+	AT_DRVINST(state)->encode_memory_type = 1;
+	AT_DRVINST(state)->encode_number = 1;
+	AT_DRVINST(state)->lac_swapped = 1;
 
+	/*
+	 * Calculate phonebook size for SonyEricsson phones: they don't respond
+	 * with memory stats to AT+CPBS. Calculate by reading and counting all
+	 * entries (which is fast -- just one command).
+	 */
 	at_insert_send_function(GN_OP_GetMemoryStatus, AT_GetMemoryStatus, state);
 	at_insert_recv_function(GN_OP_GetMemoryStatus, ReplyMemoryStatus, state);
-	at_insert_send_function(GN_OP_GetNetworkInfo, AT_GetNetworkInfo, state);
-
 }
