@@ -1,6 +1,6 @@
 /*
 
-  $Id: nk3110.c,v 1.46 2006/01/07 18:41:59 dforsi Exp $
+  $Id: nk3110.c,v 1.49 2008/05/30 19:10:06 pkot Exp $
 
   G N O K I I
 
@@ -27,7 +27,7 @@
   Copyright (C) 2003-2003 BORBELY Zoltan
   Copyright (C) 2003 Osma Suominen
 
-  This file provides functions specific to the 3110 series.
+  This file provides functions specific to the Nokia 3110 series.
   See README for more details on supported mobile phones.
 
 */
@@ -37,10 +37,6 @@
 #include <stdlib.h>
 #include <ctype.h>
 
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#endif
-
 #include "compat.h"
 #include "misc.h"
 #include "gnokii.h"
@@ -271,6 +267,7 @@ static gn_error P3110_Initialise(struct gn_statemachine *state)
 	goto retval;
 errcond:
 	FREE(DRVINSTANCE(state));
+	pgen_terminate(&data, state);
 retval:
 	return error;
 }
