@@ -1,6 +1,6 @@
 /*
 
-  $Id: vcal.c,v 1.18 2007/07/09 18:28:59 pkot Exp $
+  $Id: vcal.c,v 1.20 2007/11/07 18:28:18 pkot Exp $
 
   G N O K I I
 
@@ -65,7 +65,7 @@ static char vcal_prodid[64] = {0};
 static inline const char *get_prodid()
 {
 	if (!*vcal_prodid) {
-		sprintf(vcal_prodid, "//Gnokii.org//NONSGML v%s", gnokii_version);
+		snprintf(vcal_prodid, sizeof(vcal_prodid), "//Gnokii.org//NONSGML v%s", gnokii_version);
 	}
 	return vcal_prodid;
 }
@@ -78,7 +78,7 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 #ifdef HAVE_LIBICAL
 #  define MAX_PROP_INDEX 5
 	icalcomponent *pIcal = NULL;
-	struct icaltimetype stime = {0}, etime = {0}, atime = {0};
+	struct icaltimetype stime = {0}, etime = {0}/*, atime = {0}*/;
 	icalproperty *properties[MAX_PROP_INDEX+1] = {0}; /* order and number of properties vary */
 	int iprop = 0;
 	char compuid[64];
@@ -148,7 +148,7 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 		properties[iprop++] = icalproperty_new_summary(calnote->text);
 		do {
 			char rrule[64];
-			sprintf(rrule, "FREQ=YEARLY;INTERVAL=1;BYMONTH=%d", stime.month);
+			snprintf(rrule, sizeof(rrule), "FREQ=YEARLY;INTERVAL=1;BYMONTH=%d", stime.month);
 			properties[iprop++] = icalproperty_new_rrule(icalrecurrencetype_from_string(rrule));
 		} while (0);
 		stime.is_date = 1;
@@ -160,7 +160,7 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 		break;
 	}
 
-	sprintf(compuid, "guid.gnokii.org_%d_%d", calnote->location, rand());
+	snprintf(compuid, sizeof(compuid), "guid.gnokii.org_%d_%d", calnote->location, rand());
 
 	pIcal = icalcomponent_vanew(ICAL_VCALENDAR_COMPONENT,
 				    icalproperty_new_version("2.0"),
@@ -391,13 +391,13 @@ GNOKII_API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 		/* alarm */
 		alarm = icalcomponent_get_first_component(comp, ICAL_VALARM_COMPONENT);
 		if (alarm) {
-			struct icaldurationtype trigger_duration = {0};
-			struct icaltriggertype trigger_value = {0};
 			icalproperty *trigger = NULL;
-			struct icaltimetype alarm_start = {0};
 
 			trigger = icalcomponent_get_first_property(alarm, ICAL_TRIGGER_PROPERTY);
 			if (trigger) {
+				struct icaltriggertype trigger_value;
+				struct icaltimetype alarm_start;
+
 				trigger_value = icalvalue_get_trigger(icalproperty_get_value(trigger));
 				if (icaltriggertype_is_null_trigger(trigger_value) ||
 						icaltriggertype_is_bad_trigger(trigger_value)) {
@@ -425,11 +425,11 @@ GNOKII_API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 		}
 
 		str = icalcomponent_get_location(compresult);
-		if (!str) str = "";
+		if (!str)
+			str = "";
 		snprintf(calnote->mlocation, sizeof(calnote->mlocation), "%s", str);
 
 		dprintf("Component found\n%s\n", icalcomponent_as_ical_string(compresult));
-
 	}
 	if (compresult)
 		icalcomponent_free(compresult);
@@ -449,7 +449,7 @@ GNOKII_API int gn_todo2ical(FILE *f, gn_todo *ctodo)
 	icalcomponent *pIcal = NULL;
 	char compuid[64];
 
-	sprintf(compuid, "guid.gnokii.org_%d_%d", ctodo->location, rand());
+	snprintf(compuid, sizeof(compuid), "guid.gnokii.org_%d_%d", ctodo->location, rand());
 
 	pIcal = icalcomponent_vanew(ICAL_VCALENDAR_COMPONENT,
 				    icalproperty_new_version("2.0"),
@@ -498,7 +498,6 @@ GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
 #ifdef HAVE_LIBICAL
 	icalparser *parser = NULL;
 	icalcomponent *comp = NULL, *compresult = NULL;
-	struct icaltimetype dtstart = {0};
 
 	parser = icalparser_new();
 	if (!parser) {
@@ -523,7 +522,6 @@ GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
 		dprintf("No component found.\n");
 		return GN_ERR_EMPTYLOCATION;
 	} else {
-		const char *priostr = NULL;
 		icalproperty *priority = icalcomponent_get_first_property(compresult, ICAL_PRIORITY_PROPERTY);
 
 		/* summary goes into text */
