@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-dial.c,v 1.13 2007/11/07 18:28:19 pkot Exp $
+  $Id: gnokii-dial.c,v 1.15 2008/04/14 21:17:27 dforsi Exp $
 
   G N O K I I
 
@@ -38,7 +38,6 @@
 */
 
 #include "config.h"
-#include "misc.h"
 #include "compat.h"
 
 #include <stdio.h>
@@ -77,7 +76,7 @@ void getspeeddial_usage(FILE *f, int exitval)
 }
 
 /* Getting speed dials. */
-int getspeeddial(char *number, gn_data *data, struct gn_statemachine *state)
+gn_error getspeeddial(char *number, gn_data *data, struct gn_statemachine *state)
 {
 	gn_speed_dial	speeddial;
 	gn_error	error;
@@ -114,7 +113,7 @@ void setspeeddial_usage(FILE *f, int exitval)
 }
 
 /* Setting speed dials. */
-int setspeeddial(char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error setspeeddial(char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_speed_dial entry;
 	gn_error error;
@@ -132,7 +131,7 @@ int setspeeddial(char *argv[], gn_data *data, struct gn_statemachine *state)
 		memory_type_string = "SM";
 	} else {
 		fprintf(stderr, _("Unknown memory type %s (use ME, SM, ...)!\n"), argv[optind]);
-		return -1;
+		return GN_ERR_INVALIDMEMORYTYPE;
 	}
 
 	entry.number = gnokii_atoi(optarg);
@@ -157,7 +156,7 @@ int setspeeddial(char *argv[], gn_data *data, struct gn_statemachine *state)
 }
 
 /* Voice dialing mode. */
-int dialvoice(char *number, gn_data *data, struct gn_statemachine *state)
+gn_error dialvoice(char *number, gn_data *data, struct gn_statemachine *state)
 {
     	gn_call_info call_info;
 	gn_error error;
@@ -179,7 +178,7 @@ int dialvoice(char *number, gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-int senddtmf(char *string, gn_data *data, struct gn_statemachine *state)
+gn_error senddtmf(char *string, gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 
@@ -204,7 +203,7 @@ void answercall_usage(FILE *f, int exitval)
 }
 
 /* Answering incoming call */
-int answercall(char *callid, gn_data *data, struct gn_statemachine *state)
+gn_error answercall(char *callid, gn_data *data, struct gn_statemachine *state)
 {
     	gn_call_info callinfo;
 	gn_error error;
@@ -235,7 +234,7 @@ void hangup_usage(FILE *f, int exitval)
 }
 
 /* Hangup the call */
-int hangup(char *callid, gn_data *data, struct gn_statemachine *state)
+gn_error hangup(char *callid, gn_data *data, struct gn_statemachine *state)
 {
     	gn_call_info callinfo;
 	gn_error error;
@@ -288,7 +287,7 @@ void divert_usage(FILE *f, int exitval)
    --timeout, -m time_in_seconds                     OPT
    --number, -n number                               OPT
  */
-int divert(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error divert(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	int opt;
 	gn_call_divert cd;
@@ -374,48 +373,11 @@ int divert(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 	error = gn_sm_functions(GN_OP_CallDivert, data, state);
 
 	if (error == GN_ERR_NONE) {
-		fprintf(stdout, _("Divert type: "));
-		switch (cd.type) {
-		case GN_CDV_AllTypes:
-			fprintf(stdout, _("all\n"));
-			break;
-		case GN_CDV_Busy:
-			fprintf(stdout, _("busy\n"));
-			break;
-		case GN_CDV_NoAnswer:
-			fprintf(stdout, _("noans\n"));
-			break;
-		case GN_CDV_OutOfReach:
-			fprintf(stdout, _("outofreach\n"));
-			break;
-		case GN_CDV_NotAvailable:
-			fprintf(stdout, _("notavail\n"));
-			break;
-		default:
-			fprintf(stdout, _("unknown(0x%02x)\n"), cd.type);
-			break;
-		}
-		fprintf(stdout, _("Call type: "));
-		switch (cd.ctype) {
-		case GN_CDV_AllCalls:
-			fprintf(stdout, _("all\n"));
-			break;
-		case GN_CDV_VoiceCalls:
-			fprintf(stdout, _("voice\n"));
-			break;
-		case GN_CDV_FaxCalls:
-			fprintf(stdout, _("fax\n"));
-			break;
-		case GN_CDV_DataCalls:
-			fprintf(stdout, _("data\n"));
-			break;
-		default:
-			fprintf(stdout, _("unknown(0x%02x)\n"), cd.ctype);
-			break;
-		}
+		fprintf(stdout, _("%s: %s\n"), _("Divert type"), gn_call_divert_type2str(cd.type));
+		fprintf(stdout, _("%s: %s\n"), _("Call type"), gn_call_divert_call_type2str(cd.ctype));
 		if (cd.number.number[0]) {
-			fprintf(stdout, _("Number: %s\n"), cd.number.number);
-			fprintf(stdout, _("Timeout: %d\n"), cd.timeout);
+			fprintf(stdout, _("%s: %s\n"), _("Number"), cd.number.number);
+			fprintf(stdout, _("%s: %d\n"), _("Timeout"), cd.timeout);
 		} else
 			fprintf(stdout, _("Divert isn't active.\n"));
 	} else {
