@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-other.c,v 1.7 2007/10/05 20:34:42 pkot Exp $
+  $Id: gnokii-other.c,v 1.12 2008/05/30 17:09:14 pkot Exp $
 
   G N O K I I
 
@@ -67,7 +67,7 @@ void other_usage(FILE *f)
 /* pmon allows fbus code to run in a passive state - it doesn't worry about
    whether comms are established with the phone.  A debugging/development
    tool. */
-int pmon(gn_data *data, struct gn_statemachine *state)
+gn_error pmon(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 
@@ -83,10 +83,10 @@ int pmon(gn_data *data, struct gn_statemachine *state)
 		usleep(50000);
 	}
 
-	return 0;
+	return GN_ERR_NONE;
 }
 
-static int presskey(gn_data *data, struct gn_statemachine *state)
+static gn_error presskey(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 	error = gn_sm_functions(GN_OP_PressPhoneKey, data, state);
@@ -97,7 +97,7 @@ static int presskey(gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-int presskeysequence(gn_data *data, struct gn_statemachine *state)
+gn_error presskeysequence(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error = GN_ERR_NONE;
 	unsigned char *syms = "0123456789#*PGR+-UDMN";
@@ -124,7 +124,7 @@ int presskeysequence(gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-int enterchar(gn_data *data, struct gn_statemachine *state)
+gn_error enterchar(gn_data *data, struct gn_statemachine *state)
 {
 	unsigned char ch;
 	gn_error error = GN_ERR_NONE;
@@ -172,33 +172,39 @@ void list_gsm_networks(void)
 		printf(_("%-7s  %s\n"), network.code, network.name);
 }
 
-int getnetworkinfo(gn_data *data, struct gn_statemachine *state)
+gn_error getnetworkinfo(gn_data *data, struct gn_statemachine *state)
 {
 	gn_network_info networkinfo;
 	gn_error error;
-	int cid, lac;
+	int lac, cid;
 	char country[4] = {0, 0, 0, 0};
 
 	gn_data_clear(data);
 	memset(&networkinfo, 0, sizeof(networkinfo));
 
 	data->network_info = &networkinfo;
+	data->reg_notification = NULL;
+	data->callback_data = NULL;
 
 	if ((error = gn_sm_functions(GN_OP_GetNetworkInfo, data, state)) != GN_ERR_NONE) {
 		fprintf(stderr, _("Error: %s\n"), gn_error_print(error));
 		return error;
 	}
 
-	cid = (networkinfo.cell_id[0] << 8) + networkinfo.cell_id[1];
+	/* Ugly, ugly, ... */
+        if (networkinfo.cell_id[2] == 0 && networkinfo.cell_id[3] == 0)  
+        	cid = (networkinfo.cell_id[0] << 8) + networkinfo.cell_id[1];
+	else  
+		cid = (networkinfo.cell_id[0] << 24) + (networkinfo.cell_id[1] << 16) + (networkinfo.cell_id[2] << 8) + networkinfo.cell_id[3];
 	lac = (networkinfo.LAC[0] << 8) + networkinfo.LAC[1];
 	memcpy(country, networkinfo.network_code, 3);
 
 	fprintf(stdout, _("Network      : %s (%s)\n"),
 			gn_network_name_get((char *)networkinfo.network_code),
 			gn_country_name_get((char *)country));
-	fprintf(stdout, _("Network code : %s\n"), networkinfo.network_code);
-	fprintf(stdout, _("LAC          : %04x\n"), lac);
-	fprintf(stdout, _("Cell id      : %04x\n"), cid);
+	fprintf(stdout, _("Network code : %s\n"), (*networkinfo.network_code ? networkinfo.network_code : _("undefined")));
+	fprintf(stdout, _("LAC          : %04x (%d)\n"), lac, lac);
+	fprintf(stdout, _("Cell id      : %08x (%d)\n"), cid, cid);
 
 	return 0;
 }
