@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-sms.c,v 1.39 2008/03/14 21:39:42 dforsi Exp $
+  $Id: gnokii-sms.c,v 1.42 2008/05/29 14:39:36 pkot Exp $
 
   G N O K I I
 
@@ -121,7 +121,7 @@ void sendsms_usage(FILE *f, int exitval)
 }
 
 /* Send SMS messages. */
-int sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms sms;
 	gn_error error;
@@ -186,7 +186,7 @@ int sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 				sendsms_usage(stderr, -1);
 			if (input_len > 255 * GN_SMS_MAX_LENGTH) {
 				fprintf(stderr, _("Input too long! (%d, maximum is %d)\n"), input_len, 255 * GN_SMS_MAX_LENGTH);
-				return -1;
+				return GN_ERR_FAILED;
 			}
 			break;
 
@@ -262,7 +262,7 @@ int sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 				return error;
 			if (sms.user_data[0].length < 1) {
 				fprintf(stderr, _("Empty message. Quitting.\n"));
-				return -1;
+				return GN_ERR_FAILED;
 			}
 			curpos = -1;
 			break;
@@ -274,7 +274,7 @@ int sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 			
 			if (!optarg || strlen(optarg) > 255) {
 				fprintf(stderr, _("URL is too long (max 255 chars). Quitting.\n"));
-			        return -1;
+			        return GN_ERR_FAILED;
 			}
 			
 			sms.user_data[curpos].type = GN_SMS_DATA_WAPPush;
@@ -290,7 +290,7 @@ int sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 			
 			if (gn_wap_push_encode(&wp) != GN_ERR_NONE) {
 			    fprintf(stderr, _("WAP Push encoding failed!\n"));
-			    return -1;
+			    return GN_ERR_FAILED;
 			}
 
 			memcpy(sms.user_data[curpos].u.text, wp.data, wp.data_len);
@@ -332,7 +332,7 @@ int sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 		if (error != GN_ERR_NONE) return error;
 		if (sms.user_data[curpos].length < 1) {
 			fprintf(stderr, _("Empty message. Quitting.\n"));
-			return -1;
+			return GN_ERR_FAILED;
 		}
 		sms.user_data[curpos].type = GN_SMS_DATA_Text;
 		if (!gn_char_def_alphabet(sms.user_data[curpos].u.text))
@@ -382,7 +382,7 @@ void savesms_usage(FILE *f, int exitval)
 	exit(exitval);
 }
 
-int savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms sms;
 	gn_error error = GN_ERR_INTERNALERROR;
@@ -621,7 +621,7 @@ void getsms_usage(FILE *f, int exitval)
 }
 
 /* Get SMS messages. */
-int getsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error getsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	int i, del = 0;
 	gn_sms_folder folder;
@@ -650,7 +650,7 @@ int getsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 	memory_type_string = optarg;
 	if (gn_str2memory_type(memory_type_string) == GN_MT_XX) {
 		fprintf(stderr, _("Unknown memory type %s (use ME, SM, IN, OU, ...)!\n"), optarg);
-		return -1;
+		return GN_ERR_FAILED;
 	}
 
 	start_message = gnokii_atoi(argv[optind]);
@@ -709,26 +709,9 @@ parsefile:
 		switch (error) {
 		case GN_ERR_NONE:
 			message_text = NULL;
+			fprintf(stdout, _("%d. %s (%s)\n"), message.number, gn_sms_message_type2str(message.type), gn_sms_message_status2str(message.status));
 			switch (message.type) {
 			case GN_SMS_MT_DeliveryReport:
-				fprintf(stdout, _("%d. Delivery Report "), message.number);
-				switch (message.status) {
-				case GN_SMS_Read:
-					fprintf(stdout, _("(read)\n"));
-					break;
-				case GN_SMS_Unread:
-					fprintf(stdout, _("(unread)\n"));
-					break;
-				case GN_SMS_Sent:
-					fprintf(stdout, _("(sent)\n"));
-					break;
-				case GN_SMS_Unsent:
-					fprintf(stdout, _("(unsent)\n"));
-					break;
-				default:
-					fprintf(stdout, _("(read)\n"));
-					break;
-				}
 				fprintf(stdout, _("Sending date/time: %02d/%02d/%04d %02d:%02d:%02d "), \
 					message.smsc_time.day, message.smsc_time.month, message.smsc_time.year, \
 					message.smsc_time.hour, message.smsc_time.minute, message.smsc_time.second);
@@ -755,31 +738,6 @@ parsefile:
 				break;
 			case GN_SMS_MT_Picture:
 			case GN_SMS_MT_PictureTemplate:
-				switch (message.type) {
-				case GN_SMS_MT_PictureTemplate:
-					fprintf(stdout, _("%d. Picture Message Template "), message.number);
-					break;
-				default:
-					fprintf(stdout, _("%d. Picture Message "), message.number);
-					break;
-				}
-				switch (message.status) {
-				case GN_SMS_Read:
-					fprintf(stdout, _("(read)\n"));
-					break;
-				case GN_SMS_Unread:
-					fprintf(stdout, _("(unread)\n"));
-					break;
-				case GN_SMS_Sent:
-					fprintf(stdout, _("(sent)\n"));
-					break;
-				case GN_SMS_Unsent:
-					fprintf(stdout, _("(unsent)\n"));
-					break;
-				default:
-					fprintf(stdout, _("(read)\n"));
-					break;
-				}
 				fprintf(stdout, _("Date/time: %02d/%02d/%04d %02d:%02d:%02d "), \
 					message.smsc_time.day, message.smsc_time.month, message.smsc_time.year, \
 					message.smsc_time.hour, message.smsc_time.minute, message.smsc_time.second);
@@ -797,32 +755,6 @@ parsefile:
 				message_text = message.user_data[1].u.text;
 				break;
 			default:
-				switch (message.type) {
-				case GN_SMS_MT_Submit:
-				case GN_SMS_MT_SubmitSent:
-					fprintf(stdout, _("%d. MO Message "), message.number);
-					break;
-				default:
-					fprintf(stdout, _("%d. Inbox Message "), message.number);
-					break;
-				}
-				switch (message.status) {
-				case GN_SMS_Read:
-					fprintf(stdout, _("(read)\n"));
-					break;
-				case GN_SMS_Unread:
-					fprintf(stdout, _("(unread)\n"));
-					break;
-				case GN_SMS_Sent:
-					fprintf(stdout, _("(sent)\n"));
-					break;
-				case GN_SMS_Unsent:
-					fprintf(stdout, _("(unsent)\n"));
-					break;
-				default:
-					fprintf(stdout, _("(read)\n"));
-					break;
-				}
 				fprintf(stdout, _("Date/time: %02d/%02d/%04d %02d:%02d:%02d "), \
 					message.smsc_time.day, message.smsc_time.month, message.smsc_time.year, \
 					message.smsc_time.hour, message.smsc_time.minute, message.smsc_time.second);
@@ -845,9 +777,9 @@ parsefile:
 				/* No UDH */
 				if (!message.udh.number)
 					message.udh.udh[0].type = GN_SMS_UDH_None;
+				fprintf(stdout, _("%s:\n"), gn_sms_udh_type2str(message.udh.udh[0].type));
 				switch (message.udh.udh[0].type) {
 				case GN_SMS_UDH_None:
-					fprintf(stdout, _("Text:\n"));
 					break;
 				case GN_SMS_UDH_OpLogo:
 					fprintf(stdout, _("GSM operator logo for %s (%s) network.\n"), bitmap.netcode, gn_network_name_get(bitmap.netcode));
@@ -857,7 +789,6 @@ parsefile:
 						fprintf(stdout, _("Saved by Operator Logo Uploader by Thomas Kessler\n"));
 					offset = 3;
 				case GN_SMS_UDH_CallerIDLogo:
-					fprintf(stdout, _("Logo:\n"));
 					/* put bitmap into bitmap structure */
 					gn_bmp_sms_read(GN_BMP_OperatorLogo, message.user_data[0].u.text + 2 + offset, message.user_data[0].u.text, &bitmap);
 					gn_bmp_print(&bitmap, stdout);
@@ -881,7 +812,6 @@ parsefile:
 					done = true;
 					break;
 				case GN_SMS_UDH_Ringtone:
-					fprintf(stdout, _("Ringtone\n"));
 					done = true;
 					break;
 				case GN_SMS_UDH_ConcatenatedMessages:
@@ -890,19 +820,10 @@ parsefile:
 						message.udh.udh[0].u.concatenated_short_message.maximum_number);
 					break;
 				case GN_SMS_UDH_WAPvCard:
-					fprintf(stdout, _("WAP vCard:\n"));
-					break;
 				case GN_SMS_UDH_WAPvCalendar:
-					fprintf(stdout, _("WAP vCalendar:\n"));
-					break;
 				case GN_SMS_UDH_WAPvCardSecure:
-					fprintf(stdout, _("WAP vCardSecure:\n"));
-					break;
 				case GN_SMS_UDH_WAPvCalendarSecure:
-					fprintf(stdout, _("WAP vCalendarSecure:\n"));
-					break;
 				default:
-					fprintf(stderr, _("Unknown\n"));
 					break;
 				}
 				if (done)
@@ -962,7 +883,7 @@ void deletesms_usage(FILE *f, int exitval)
 }
 
 /* Delete SMS messages. */
-int deletesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error deletesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms message;
 	gn_sms_folder folder;
@@ -976,7 +897,7 @@ int deletesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *sta
 	message.memory_type = gn_str2memory_type(memory_type_string);
 	if (message.memory_type == GN_MT_XX) {
 		fprintf(stderr, _("Unknown memory type %s (use ME, SM, ...)!\n"), optarg);
-		return -1;
+		return GN_ERR_INVALIDMEMORYTYPE;
 	}
 
 	start_message = gnokii_atoi(argv[optind]);
@@ -1028,7 +949,7 @@ void getsmsc_usage(FILE *f, int exitval)
 }
 
 /* Get SMSC number */
-int getsmsc(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error getsmsc(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_message_center message_center;
 	gn_error error;
@@ -1064,12 +985,12 @@ int getsmsc(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 
 		if (start > stop) {
 			fprintf(stderr, _("Starting SMS center number is greater than stop\n"));
-			return -1;
+			return GN_ERR_FAILED;
 		}
 
 		if (start < 1) {
 			fprintf(stderr, _("SMS center number must be greater than 0\n"));
-			return -1;
+			return GN_ERR_FAILED;
 		}
 	} else {
 		start = 1;
@@ -1108,66 +1029,16 @@ int getsmsc(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 			else
 				fprintf(stdout, _("No. %d: \"%s\" (default name)\n"), message_center.id, message_center.name);
 			fprintf(stdout, _("SMS center number is %s\n"), message_center.smsc.number);
-			fprintf(stdout, _("Default recipient number is %s\n"), message_center.recipient.number);
-			fprintf(stdout, _("Messages sent as "));
-
-			switch (message_center.format) {
-			case GN_SMS_MF_Text:
-				fprintf(stdout, _("Text"));
-				break;
-			case GN_SMS_MF_Voice:
-				fprintf(stdout, _("VoiceMail"));
-				break;
-			case GN_SMS_MF_Fax:
-				fprintf(stdout, _("Fax"));
-				break;
-			case GN_SMS_MF_Email:
-			case GN_SMS_MF_UCI:
-				fprintf(stdout, _("Email"));
-				break;
-			case GN_SMS_MF_ERMES:
-				fprintf(stdout, _("ERMES"));
-				break;
-			case GN_SMS_MF_X400:
-				fprintf(stdout, _("X.400"));
-				break;
-			default:
-				fprintf(stdout, _("Unknown"));
-				break;
-			}
-
-			fprintf(stdout, "\n");
-			fprintf(stdout, _("Message validity is "));
-
-			switch (message_center.validity) {
-			case GN_SMS_VP_1H:
-				fprintf(stdout, _("1 hour"));
-				break;
-			case GN_SMS_VP_6H:
-				fprintf(stdout, _("6 hours"));
-				break;
-			case GN_SMS_VP_24H:
-				fprintf(stdout, _("24 hours"));
-				break;
-			case GN_SMS_VP_72H:
-				fprintf(stdout, _("72 hours"));
-				break;
-			case GN_SMS_VP_1W:
-				fprintf(stdout, _("1 week"));
-				break;
-			case GN_SMS_VP_Max:
-				fprintf(stdout, _("Maximum time"));
-				break;
-			default:
-				fprintf(stdout, _("Unknown"));
-				break;
-			}
-
-			fprintf(stdout, "\n");
+			if (message_center.recipient.number[0])
+				fprintf(stdout, _("Default recipient number is %s\n"), message_center.recipient.number);
+			else
+				fprintf(stdout, _("No default recipient number is defined\n"));
+			fprintf(stdout, _("Messages sent as %s\n"), gn_sms_message_format2str(message_center.format));
+			fprintf(stdout, _("Message validity is %s\n"), gn_sms_vp_time2str(message_center.validity));
 		}
 	}
 
-	return 0;
+	return GN_ERR_NONE;
 }
 
 /* Displays usage of --setsmsc command */
@@ -1181,7 +1052,7 @@ void setsmsc_usage(FILE *f, int exitval)
 }
 
 /* Set SMSC number */
-int setsmsc(gn_data *data, struct gn_statemachine *state)
+gn_error setsmsc(gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_message_center message_center;
 	gn_error error;
@@ -1237,7 +1108,7 @@ void createsmsfolder_usage(FILE *f, int exitval)
 }
 
 /* Creating SMS folder. */
-int createsmsfolder(char *name, gn_data *data, struct gn_statemachine *state)
+gn_error createsmsfolder(char *name, gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_folder	folder;
 	gn_error	error;
@@ -1265,7 +1136,7 @@ void deletesmsfolder_usage(FILE *f, int exitval)
 }
 
 /* Deleting SMS folder. */
-int deletesmsfolder(char *number, gn_data *data, struct gn_statemachine *state)
+gn_error deletesmsfolder(char *number, gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_folder	folder;
 	gn_error	error;
@@ -1295,7 +1166,7 @@ void showsmsfolderstatus_usage(FILE *f, int exitval)
 	exit(exitval);
 }
 
-int showsmsfolderstatus(gn_data *data, struct gn_statemachine *state)
+gn_error showsmsfolderstatus(gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_folder_list folders;
 	gn_error error;
@@ -1394,7 +1265,7 @@ void smsreader_usage(FILE *f, int exitval)
 	exit(exitval);
 }
 
-int smsreader(gn_data *data, struct gn_statemachine *state)
+gn_error smsreader(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 
