@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokiid.c,v 1.46 2006/05/08 19:20:07 deller Exp $
+  $Id: gnokiid.c,v 1.58 2008/05/08 13:37:06 dforsi Exp $
 
   G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999-2000  Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000  Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2001-2004  Pawel Kot
   Copyright (C) 2002       Manfred Jonsson
   Copyright (C) 2002-2003  BORBELY Zoltan
@@ -32,6 +32,8 @@
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -42,8 +44,14 @@
 #include <sys/time.h>
 #include <string.h>
 
+#include "config.h"
+
+#ifdef ENABLE_NLS
+#  include <locale.h>
+#endif
+
 #include "misc.h"
-#include "gnokii.h"
+#include "gnokii-internal.h"
 
 /* Global variables */
 bool DebugMode;		/* When true, run in debug mode */
@@ -70,7 +78,7 @@ static void version()
 static void usage()
 {
 
-	fprintf(stderr, _("   usage: gnokiid {--help|--version}\n"
+	fprintf(stderr, _("   usage: gnokiid [--help|--version|--debug]\n"
 "          --help            display usage information\n"
 "          --version         displays version and copyright information\n"
 "          --debug           uses stdin/stdout for virtual modem comms\n"));
@@ -95,40 +103,62 @@ int main(int argc, char *argv[])
 
 	/* For GNU gettext */
 #ifdef ENABLE_NLS
-	textdomain("gnokii");
+	setlocale(LC_ALL, "");
+	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+	textdomain(GETTEXT_PACKAGE);
 #endif
 
 	short_version();
 
+	/* Handle command line arguments. */
+	switch (argc) {
+	case 1:
+		/* Default */
+		DebugMode = false;
+		break;
+	case 2:
+		if (strcmp(argv[1], "--version") == 0) {
+			/* Display version, copyright and build information. */
+			version();
+			exit(0);
+		} else if (strcmp(argv[1], "--debug") == 0) {
+			/* Use stdin/stdout for I/O */
+			DebugMode = true;
+			break;
+		} else if (strcmp(argv[1], "--help") == 0) {
+			usage();
+			exit(0);
+		}
+		/* FALL TROUGH */
+	default:
+		usage();
+		exit(1);
+	}
+
+	aux = gn_lib_cfg_get("global", "model");
+	if (!aux) {
+		fprintf(stderr, "%s\n", gn_error_print(GN_ERR_NOCONFIG));
+		exit(1);
+		}
+
+	if (strncmp(aux, "5110", 4) &&
+	    strncmp(aux, "5130", 4) &&
+	    strncmp(aux, "6110", 4) &&
+	    strncmp(aux, "6130", 4) &&
+	    strncmp(aux, "6150", 4)) {
+		fprintf(stderr, _("gnokiid purpose is to work only with the phones that do not have AT Hayes\ncommands interpreter.\n"));
+		exit(1);
+	}
+
 	BinDir = gn_lib_cfg_get("global", "bindir");
 	if (!BinDir) BinDir = gn_lib_cfg_get("gnokiid", "bindir");
-	if (!BinDir) BinDir = "/usr/local/sbin";
+	if (!BinDir) BinDir = SBINDIR;
 
-	if (!gn_cfg_phone_load("", &temp_state)) exit(-1);
-
-	/* Handle command line arguments. */
-	if (argc >= 2 && strcmp(argv[1], "--help") == 0) {
-		usage();
-		exit(0);
-	}
-
-	/* Display version, copyright and build information. */
-	if (argc >= 2 && strcmp(argv[1], "--version") == 0) {
-		version();
-		exit(0);
-	}
-
-	if (argc >= 2 && strcmp(argv[1], "--debug") == 0) {
-		DebugMode = true;
-	} else {
-		DebugMode = false;
-	}
+	if (gn_cfg_phone_load("", &temp_state) != GN_ERR_NONE) exit(-1);
 
 	gn_elog_handler = NULL;
 
-	aux = gn_lib_cfg_get("global", "use_locking");
-	/* Defaults to 'no' */
-	if (aux && !strcmp(aux, "yes")) {
+	if (temp_state.config.use_locking) {
 		lockfile = gn_device_lock(temp_state.config.port_device);
 		if (lockfile == NULL) {
 			fprintf(stderr, _("Lock file error. Exiting.\n"));
