@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii.h,v 1.120 2007/11/24 11:26:23 pkot Exp $
+  $Id: gnokii.h.in,v 1.7 2008/05/30 15:33:00 dforsi Exp $
 
   G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999-2000 Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000 Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2001-2005 Pawel Kot
   Copyright (C) 2001      Chris Kemp
   copyright (C) 2002      Markus Plail
@@ -44,7 +44,7 @@ extern "C" {
 #if defined(__linux__) || defined(__GLIBC__) || defined(__CYGWIN__)
 #  include <stdint.h>
 #  include <sys/time.h>
-#elif defined(__svr4__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(__MACH__)
+#elif defined(__svr4__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(__MACH__)
 #  include <inttypes.h>
 #  include <sys/time.h>
 #elif defined(_MSC_VER) && defined(WIN32)
@@ -64,14 +64,9 @@ typedef unsigned char uint8_t;
 #  endif
 #endif
 
-/* if you change those numbers, change them in common/Makefile as well! */
-/* LIBGNOKII_VERSION_MAJOR = GNOKII_MAJOR - GNOKII_MINOR
- * LIBGNOKII_VERSION_MINOR = GNOKII_MINOR
- * LIBGNOKII_VERSION_RELEASE = GNOKII_RELEASE
- */
-#define LIBGNOKII_VERSION_STRING "3.6.0"
+#define LIBGNOKII_VERSION_STRING "3.9.0"
 #define LIBGNOKII_VERSION_MAJOR 3
-#define LIBGNOKII_VERSION_MINOR 6
+#define LIBGNOKII_VERSION_MINOR 9
 #define LIBGNOKII_VERSION_RELEASE 0
 #define LIBGNOKII_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
 
@@ -182,7 +177,7 @@ GNOKII_API gn_error gn_lib_set_pb_subentry    ( struct gn_statemachine *state, c
 GNOKII_API gn_error gn_lib_phonebook_write_entry( struct gn_statemachine *state,
         const gn_memory_type memory_type, const int index );
 
-GNOKII_API char *gn_subentrytype2string(gn_phonebook_entry_type entry_type, gn_phonebook_number_type number_type);
+GNOKII_API const char *gn_subentrytype2string(gn_phonebook_entry_type entry_type, gn_phonebook_number_type number_type);
 
 /* standard helper functions */
 
@@ -203,6 +198,11 @@ GNOKII_API gn_error gn_lib_search_one_connected_phone( struct gn_statemachine **
    config file */
 GNOKII_API const char *gn_lib_get_connection_name(gn_connection_type ct);
 
+/* use this function to get the enum corresponding to the given connection name.
+   Returns GN_CT_NONE if the connection is unknown or its support isn't compiled
+   in the running library */
+GNOKII_API gn_connection_type gn_get_connectiontype(const char *connection_type_string);
+
 /* use this function to check whether the connection type is enabled
    0 - not supported
    1 - supported */
@@ -211,6 +211,7 @@ GNOKII_API int gn_lib_is_connectiontype_supported(gn_connection_type ct);
 /* Misc */
 GNOKII_API gn_memory_type gn_str2memory_type(const char *s);
 GNOKII_API const char *gn_memory_type2str(gn_memory_type mt);
+GNOKII_API const char *gn_memory_type_print(gn_memory_type mt);
 GNOKII_API int gn_timestamp_isvalid(const gn_timestamp dt);
 GNOKII_API void gn_timestamp_set(gn_timestamp *dt, int year, int month, int day,
 			int hour, int minute, int second, int timezone);
@@ -254,7 +255,6 @@ GNOKII_API gn_error gn_gsm_initialise(struct gn_statemachine *sm) GNOKII_DEPRECA
 /* Config handling */
 /* Get the key value from the given config, given section and the key name */
 GNOKII_API char *gn_cfg_get(struct gn_cfg_header *cfg, const char *section, const char *key) GNOKII_DEPRECATED;
-GNOKII_API gn_error gn_cfg_read(char **bindir) GNOKII_DEPRECATED;
 /* Read the config from the file filename */
 GNOKII_API gn_error gn_cfg_file_read(const char *filename) GNOKII_DEPRECATED;
 /* Read the config from the file already put into the memory */
