@@ -1,6 +1,6 @@
 /*
 
-  $Id: atgen.h,v 1.31 2007/11/19 13:26:10 pkot Exp $
+  $Id: atgen.h,v 1.34 2008/05/30 17:17:25 pkot Exp $
 
   G N O K I I
 
@@ -24,7 +24,7 @@
 
   Copyright (C) 2000 Hugh Blemings, Pavel Janik
   Copyright (C) 2001 Manfred Jonsson <manfred.jonsson@gmx.de>
-  Copyright (C) 2002 Pawel Kot
+  Copyright (C) 2002-2008 Pawel Kot
   Copyright (C) 2003 Ladis Michl
   Copyright (C) 2004 Ron Yorston, Hugo Hass
 
@@ -37,6 +37,7 @@
 #define _gnokii_atgen_h_
 
 #include "gnokii-internal.h"
+#include "map.h"
 
 typedef enum {
 	GN_OP_AT_GetCharset = GN_OP_Max,
@@ -111,13 +112,48 @@ typedef struct {
 	void (*on_cell_broadcast)(gn_cb_message *msg, struct gn_statemachine *state, void *callback_data);
 	void (*call_notification)(gn_call_status call_status, gn_call_info *call_info, struct gn_statemachine *state, void *callback_data);
 	gn_error (*on_sms)(gn_sms *message, struct gn_statemachine *state, void *callback_data);
+	void (*reg_notification)(gn_network_info *info, void *callback_data);
 
 	/* callback local data */
-	void *cb_callback_data;	/* to be passed as callback_data to on_cell_broadcast */
-	void *call_callback_data;	/* to be passed as callback_data to call_notification */
-	void *sms_callback_data;	/* to be passed as callback_data to on_sms */
+	/* to be passed as callback_data to on_cell_broadcast */
+	void *cb_callback_data;
+	/* to be passed as callback_data to call_notification */
+	void *call_callback_data;
+	/* to be passed as callback_data to on_sms */
+	void *sms_callback_data;
+	/* to be passed as callback_data to reg_notification */
+	void *reg_callback_data;
 
 	char *timezone;
+
+	/* indicates whether phone is in PDU mode */
+	int pdumode;
+
+	/* cached information for AT+XXXX=? commands */
+	struct map *cached_capabilities;
+
+	/*
+	 * Indicated whether phone supports extended registration status
+	 * 0 - not known (we haven't asked yet)
+	 * 1 - extended status not supported
+	 * 2 - extended status supported
+	 */
+	int extended_reg_status;
+
+	/*
+	 * Some phones use encoding setting to encode just names and the other
+	 * entities are encoded using ASCII (Nokia). Other phones encode every
+	 * output with the given encoding and require the same for the input
+	 * (Sony Ericsson).
+	 */
+	int encode_memory_type;
+	int encode_number;
+
+	/*
+	 * Some phones reply with +CREG command with LAC information but with
+	 * the bytes swapped. Default is the natural order.
+	 */
+	int lac_swapped;
 } at_driver_instance;
 
 #define AT_DRVINST(s) (*((at_driver_instance **)(&(s)->driver.driver_instance)))
