@@ -28,6 +28,9 @@
 #define NOKIA3230_PRODUCT_ID	0x0421
 #define NOKIA6230i_PRODUCT_ID	0x0428
 #define NOKIA6265_PRODUCT_ID	0x0437
+#define NOKIAN70_PRODUCT_ID	0x043a
+#define NOKIA6155_PRODUCT_ID	0x043c
 
 #define NOKIA_AT_PORT	0x82
 #define NOKIA_FBUS_PORT	0x86
+#define NOKIA_AT_PORT2	0x87
