@@ -1,6 +1,6 @@
 /*
 
-  $Id: lowlevel.c,v 1.45 2006/08/27 22:14:14 pkot Exp $
+  $Id: lowlevel.c,v 1.52 2008/05/25 11:47:43 pkot Exp $
 
   S M S D
 
@@ -27,12 +27,13 @@
 
 */
 
-#include <unistd.h>
+#include "config.h"
 #include <pthread.h>
 #include <string.h>
 #include <glib.h>
 #include "misc.h"
 #include "gnokii.h"
+#include "compat.h"
 #include "smsd.h"
 #include "lowlevel.h"
 
@@ -79,6 +80,7 @@ static gn_error InitModelInf (void)
 {
   gn_data data;
   gn_error error;
+  char *aux;
   char model[GN_MODEL_MAX_LENGTH], rev[GN_REVISION_MAX_LENGTH], 
 	manufacturer[GN_MANUFACTURER_MAX_LENGTH];
 
@@ -92,11 +94,15 @@ static gn_error InitModelInf (void)
     return error;
   }
     
-  g_free (phoneMonitor.phone.model);
+  g_free (phoneMonitor.phone.version);
   phoneMonitor.phone.version = g_strdup (model);
-  phoneMonitor.phone.model = gn_phone_model_get (model)->model;
-  if (phoneMonitor.phone.model == NULL)
+
+  g_free (phoneMonitor.phone.model);
+  aux = (char *)gn_phone_model_get(model)->model;
+  if (aux == NULL)
     phoneMonitor.phone.model = g_strdup (_("unknown"));
+  else
+    phoneMonitor.phone.model = g_strdup (aux);
 
   phoneMonitor.supported = gn_phone_model_get (model)->flags;
 
@@ -123,7 +129,8 @@ static gn_error fbusinit (const char * const iname)
 {
   gn_error error;
 
-  if (GN_ERR_NONE != gn_lib_phoneprofile_load(iname, &sm))
+  error = gn_lib_phoneprofile_load(iname, &sm);
+  if (error != GN_ERR_NONE)
   {
     g_print (_("Cannot load phone %s!\nDo you have proper section in gnokiirc?\n"), iname);
     g_print (_("%s\n"), gn_error_print(error));
@@ -156,11 +163,12 @@ static gn_error fbusinit (const char * const iname)
 void InitPhoneMonitor (void)
 {
   phoneMonitor.phone.model = g_strdup (_("unknown"));
-  phoneMonitor.phone.version = phoneMonitor.phone.model;
+  phoneMonitor.phone.version = g_strdup (_("unknown"));
   phoneMonitor.phone.revision = g_strdup (_("unknown"));
   phoneMonitor.supported = 0;
-  phoneMonitor.working = FALSE;
-  phoneMonitor.sms.unRead = phoneMonitor.sms.number = 0;
+//  phoneMonitor.working = FALSE;
+//  phoneMonitor.sms.unRead = 0;
+  phoneMonitor.sms.number = 0;
   phoneMonitor.sms.messages = NULL;
   pthread_mutex_init (&smsMutex, NULL);
   pthread_cond_init (&smsCond, NULL);
@@ -197,50 +205,79 @@ static void RefreshSMS (const gint number)
   register gint i;
   
 
-  gn_log_xdebug ("RefreshSMS is running...\n");
+  if (number < 1)
+  {
+    gn_log_xdebug ("RefreshSMS is started with number of sms less than 1.\n\
+This should not happen.\nSkiping.");
+    return;
+  }
+  
+  gn_log_xdebug ("RefreshSMS is running...\nNumber of messages: %d\n", number);
 
-  pthread_mutex_lock (&smsMutex);
   FreeArray (&(phoneMonitor.sms.messages));
   phoneMonitor.sms.number = 0;
-  pthread_mutex_unlock (&smsMutex);
 
   gn_data_clear(&data);
   data.sms_folder_list = &folderlist;
   folder.folder_id = 0;
   data.sms_folder = &folder;
-  
-  i = 0;
+
+  if (smsdConfig.firstSMS < 0)
+  {
+    gn_log_xdebug ("Detecting first SMS position.\n");
+    
+    msg = g_malloc (sizeof (gn_sms));
+    memset (msg, 0, sizeof (gn_sms));
+    msg->memory_type = smsdConfig.memoryType;
+    msg->number = 0;
+    data.sms = msg;
+
+    if ((error = gn_sms_get (&data, sm)) == GN_ERR_INVALIDLOCATION)
+      smsdConfig.firstSMS = 1;
+    else
+      smsdConfig.firstSMS = 0;
+      
+    gn_log_xdebug ("First SMS position is %d\n", smsdConfig.firstSMS);
+    
+    g_free (msg);
+  }
+    
+  i = smsdConfig.firstSMS;
   while (1)
   {
     msg = g_malloc (sizeof (gn_sms));
     memset (msg, 0, sizeof (gn_sms));
     msg->memory_type = smsdConfig.memoryType;
-    msg->number = ++i;
+    msg->number = i++;
     data.sms = msg;
-    
+    gn_log_xdebug("Reading SMS %d\n", i-1);
     if ((error = gn_sms_get (&data, sm)) == GN_ERR_NONE)
     {
-      pthread_mutex_lock (&smsMutex);
       phoneMonitor.sms.messages = g_slist_append (phoneMonitor.sms.messages, msg);
       phoneMonitor.sms.number++;
       
       if (phoneMonitor.sms.number == number)
       {
         pthread_cond_signal (&smsCond);
-        pthread_mutex_unlock (&smsMutex);
         return;
       }
-
-      pthread_mutex_unlock (&smsMutex);
     }
-    else if (error == GN_ERR_INVALIDLOCATION)   /* All positions are readed */
+    /*
+     * GN_ERR_INVALIDLOCATION indicates all positions are read.
+     * In case when we were reading location 0, ignore potential error.
+     */
+    else if (error == GN_ERR_INVALIDLOCATION && i > 1)
     {
+      gn_log_xdebug("Invalid location\n");
       g_free (msg);
       pthread_cond_signal (&smsCond);
       break;
     }
     else
+    {
       g_free (msg);
+      gn_log_xdebug ("gn_sms_get returned %d\n", error);
+    }
 
     usleep (500000);
   }
@@ -250,44 +287,44 @@ static void RefreshSMS (const gint number)
 static gint A_SendSMSMessage (gpointer data)
 {
   D_SMSMessage *d = (D_SMSMessage *) data;
-  gn_error error;
   gn_data *dt;
 
-  error = d->status = GN_ERR_UNKNOWN;
-  if (d)
-  {
-    pthread_mutex_lock (&sendSMSMutex);
-    dt = calloc (1, sizeof (gn_data));
-    if (!d->sms->smsc.number[0])
-    {
-      dt->message_center = calloc (1, sizeof (gn_sms_message_center));
-      dt->message_center->id = 1;
-      if (gn_sm_functions (GN_OP_GetSMSCenter, dt, sm) == GN_ERR_NONE)
-      {
-        strcpy (d->sms->smsc.number, dt->message_center->smsc.number);
-        d->sms->smsc.type = dt->message_center->smsc.type;
-      }
-      free (dt->message_center);
-    }
+  if (!d)
+    return (GN_ERR_UNKNOWN);
     
-    if (!d->sms->smsc.type)
-      d->sms->smsc.type = GN_GSM_NUMBER_Unknown;
-      
-    gn_data_clear (dt);
-    dt->sms = d->sms;
-    error = d->status = gn_sms_send (dt, sm);
-    free (dt);
-    pthread_cond_signal (&sendSMSCond);
-    pthread_mutex_unlock (&sendSMSMutex);
+  pthread_mutex_lock (&sendSMSMutex);
+  dt = calloc (1, sizeof (gn_data));
+  if (!d->sms->smsc.number[0])
+  {
+    dt->message_center = calloc (1, sizeof (gn_sms_message_center));
+    dt->message_center->id = 1;
+    if (gn_sm_functions (GN_OP_GetSMSCenter, dt, sm) == GN_ERR_NONE)
+    {
+      strcpy (d->sms->smsc.number, dt->message_center->smsc.number);
+      d->sms->smsc.type = dt->message_center->smsc.type;
+    }
+    free (dt->message_center);
   }
+  
+  if (!d->sms->smsc.type)
+    d->sms->smsc.type = GN_GSM_NUMBER_Unknown;
+    
+  gn_data_clear (dt);
+  dt->sms = d->sms;
+  d->status = gn_sms_send (dt, sm);
+  free (dt);
+  pthread_cond_signal (&sendSMSCond);
+  pthread_mutex_unlock (&sendSMSMutex);
 
-  if (d->status == GN_ERR_NONE)
-    return GN_ERR_NONE;
-  else
-    return (error);
+  return (d->status);
 }
 
-
+/*
+ * Argument passed here should be gn_sms structure.
+ * Required fields for sms deletion are:
+ *   - gn_sms.number
+ *   - gn_sms.memory_type
+ */
 static gint A_DeleteSMSMessage (gpointer data)
 {
   gn_data *dt;
@@ -302,9 +339,18 @@ static gint A_DeleteSMSMessage (gpointer data)
   dt->sms_folder_list = &SMSFolderList;
   if (dt->sms)
   {
+    gn_log_xdebug("Deleting SMS %d\n", dt->sms->number);
+    /* FIXME: error handling */
     error = gn_sms_delete (dt, sm);
-//    I don't use copy, I don't need free message.
-//    g_free (sms);
+
+    gn_log_xdebug("Error: %s\n", gn_error_print(error));
+    pthread_mutex_lock (&smsMutex);
+    FreeElement (data, NULL);
+    phoneMonitor.sms.messages = g_slist_remove (phoneMonitor.sms.messages, data);
+    phoneMonitor.sms.number--;
+    pthread_mutex_unlock (&smsMutex);
+  } else {
+    gn_log_xdebug("Internal error: dt->sms == NULL\n");
   }
 
   free (dt);
@@ -355,26 +401,27 @@ static void RealConnect (void *phone)
 
   while (1)
   {
-    phoneMonitor.working = FALSE;
+//    phoneMonitor.working = FALSE;
 
+    pthread_mutex_lock (&smsMutex);
+    
     if (phoneMonitor.supported & PM_FOLDERS)
     {
       data->sms_folder = &SMSFolder;
       SMSFolder.folder_id = smsdConfig.memoryType;
       if ((error = gn_sm_functions (GN_OP_GetSMSFolderStatus, data, sm)) == GN_ERR_NONE)
       {
+        gn_log_xdebug ("GN_OP_GetSMSFolderStatus returned  %d\n",
+                       SMSFolder.number);
+        gn_log_xdebug ("phoneMonitor.sms.number %d\n",
+                       phoneMonitor.sms.number);
         if (phoneMonitor.sms.number != SMSFolder.number)
         {
-          phoneMonitor.working = TRUE;
+//          phoneMonitor.working = TRUE;
           RefreshSMS (SMSFolder.number);
-          phoneMonitor.working = FALSE;
+//          phoneMonitor.working = FALSE;
         }
-        phoneMonitor.sms.unRead = 0;
-      }
-      else
-      {
-        g_print (_("GN_OP_GetSMSFolderStatus at line %d in file %s returns error %d\nRestarting connection."), __LINE__, __FILE__, error);
-        break;
+//        phoneMonitor.sms.unRead = 0;
       }
     }
     else
@@ -386,26 +433,38 @@ static void RealConnect (void *phone)
       data->memory_status = &dummy;
       if ((error = gn_sm_functions (GN_OP_GetSMSStatus, data, sm)) == GN_ERR_NONE)
       {
-        if (phoneMonitor.sms.unRead != SMSStatus.unread ||
+        gn_log_xdebug ("GN_OP_GetSMSStatus returned (number, unread) %d, %d\n",
+                       SMSStatus.number, SMSStatus.unread);
+        gn_log_xdebug ("phoneMonitor %d\n", phoneMonitor.sms.number);
+        if (/* phoneMonitor.sms.unRead != SMSStatus.unread || */
             phoneMonitor.sms.number != SMSStatus.number)
         {
-          phoneMonitor.working = TRUE;
+//          phoneMonitor.working = TRUE;
           RefreshSMS (SMSStatus.number);
-          phoneMonitor.working = FALSE;
+//          phoneMonitor.working = FALSE;
         }
-        phoneMonitor.sms.unRead = SMSStatus.unread;
+//        phoneMonitor.sms.unRead = SMSStatus.unread;
       }
-      else
+    }
+    
+    pthread_mutex_unlock (&smsMutex);
+    
+    if (error != GN_ERR_NONE)
+    {
+      if (error == GN_ERR_TIMEOUT)
       {
-        g_print (_("GN_OP_GetSMSStatus at line %d in file %s returns error %d\nRestarting connection."), __LINE__, __FILE__, error);
+        g_print (_("Timeout in file %s, line %d, restarting connection.\n"),
+                 __FILE__, __LINE__);
         break;
       }
+      else
+        g_print ("%s:%d error: %d, %s\n", __FILE__, __LINE__, error, gn_error_print(error));
     }
 
     while ((event = RemoveEvent ()) != NULL)
     {
       gn_log_xdebug ("Processing Event: %d\n", event->event);
-      phoneMonitor.working = TRUE;
+//      phoneMonitor.working = TRUE;
       if (event->event <= Event_Exit)
         if ((error = DoAction[event->event] (event->data)) != GN_ERR_NONE)
           g_print (_("Event %d failed with return code %d!\n"), event->event, error);
@@ -414,7 +473,7 @@ static void RealConnect (void *phone)
     
     sleep (smsdConfig.refreshInt);
   }
-  
+
   free (data);
 }
 
