@@ -1,6 +1,6 @@
 /*
 
-  $Id: pq.c,v 1.29 2006/02/08 22:15:46 ja Exp $
+  $Id: pq.c,v 1.32 2006/10/03 21:26:38 pkot Exp $
 
   S M S D
 
@@ -29,6 +29,7 @@
 
 */
 
+#include "config.h"
 #include <string.h>
 #include <stdlib.h>
 #include <glib.h>
@@ -36,12 +37,13 @@
 #include "smsd.h"
 #include "gnokii.h"
 #include "compat.h"
+#include "utils.h"
 
 static PGconn *connIn = NULL;
 static PGconn *connOut = NULL;
 static gchar *schema = NULL;		/* database schema */
 
-void DB_Bye (void)
+GNOKII_API void DB_Bye (void)
 {
   if (connIn)
     PQfinish (connIn);
@@ -51,7 +53,7 @@ void DB_Bye (void)
 }
 
 
-gint DB_ConnectInbox (DBConfig connect)
+GNOKII_API gint DB_ConnectInbox (DBConfig connect)
 {
   connIn = PQsetdbLogin (connect.host[0] != '\0' ? connect.host : NULL,
                          NULL,
@@ -76,7 +78,7 @@ gint DB_ConnectInbox (DBConfig connect)
 }
 
 
-gint DB_ConnectOutbox (DBConfig connect)
+GNOKII_API gint DB_ConnectOutbox (DBConfig connect)
 {
   connOut = PQsetdbLogin (connect.host[0] != '\0' ? connect.host : NULL,
                           NULL,
@@ -101,7 +103,7 @@ gint DB_ConnectOutbox (DBConfig connect)
 }
 
 
-gint DB_InsertSMS (const gn_sms * const data, const gchar * const phone)
+GNOKII_API gint DB_InsertSMS (const gn_sms * const data, const gchar * const phone)
 {
   GString *buf, *phnStr;
   gchar *text;
@@ -145,7 +147,7 @@ gint DB_InsertSMS (const gn_sms * const data, const gchar * const phone)
 }
 
 
-void DB_Look (const gchar * const phone)
+GNOKII_API void DB_Look (const gchar * const phone)
 {
   GString *buf, *phnStr;
   PGresult *res1, *res2;
