@@ -1,6 +1,6 @@
 /*
 
-  $Id: smsd.c,v 1.57 2007/07/07 14:33:04 pkot Exp $
+  $Id: smsd.c,v 1.67 2008/05/25 11:47:44 pkot Exp $
 
   S M S D
 
@@ -22,11 +22,13 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   Copyright (C) 1999-2005 Jan Derfinak
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
@@ -34,8 +36,6 @@
 #include <pthread.h>
 #include <getopt.h>
 #include <time.h>
-#include <dlfcn.h>
-
 
 #ifndef WIN32
 # include <unistd.h>  /* for usleep */
@@ -49,11 +49,11 @@
 #endif
 
 #include <glib.h>
+#include <gmodule.h>
 
 #include "misc.h"
 
 #include "gnokii.h"
-#include "config.h"
 #include "smsd.h"
 #include "lowlevel.h"
 #include "db.h"
@@ -84,65 +84,61 @@ static volatile bool db_monitor;
 
 gint LoadDB (void)
 {
-  void *handle;
-  GString *buf;
-  gchar *error;
-  
-  buf = g_string_sized_new (64);
-  
-  g_string_sprintf (buf, "%s/lib%s.so", smsdConfig.libDir, smsdConfig.dbMod);
+  GModule *handle;
+  gchar *buf;
+  gchar *full_name;
 
-  gn_log_xdebug ("Trying to load module %s\n", buf->str);
+  full_name = g_strdup_printf ("smsd_%s", smsdConfig.dbMod);
+  buf = g_module_build_path(smsdConfig.libDir, full_name);
+  g_free (full_name);
+  
+  gn_log_xdebug("Trying to load module %s\n", buf);
     
-  handle = dlopen (buf->str, RTLD_LAZY);
+  handle = g_module_open(buf, G_MODULE_BIND_LAZY);
+  g_free (buf);
   if (!handle)
   {
-    g_print ("dlopen error: %s!\n", dlerror());
+    g_print ("g_module_open error: %s!\n", g_module_error ());
     return (1);
   }
     
-  DB_Bye = dlsym(handle, "DB_Bye");
-  if ((error = dlerror ()) != NULL)
+  if (g_module_symbol(handle, "DB_Bye", (gpointer *)&DB_Bye) == FALSE)
   {
-    g_print ("%s\n", error);
+    g_print ("Error getting symbol 'DB_Bye': %s\n", g_module_error ());
     return (2);
   }
 
-  DB_ConnectInbox = dlsym(handle, "DB_ConnectInbox");
-  if ((error = dlerror ()) != NULL)
+  if (g_module_symbol(handle, "DB_ConnectInbox", (gpointer *)&DB_ConnectInbox) == FALSE)
   {
-    g_print ("%s\n", error);
+    g_print ("Error getting symbol 'DB_ConnectInbox':  %s\n", g_module_error ());
     return (2);
   }
 
-  DB_ConnectOutbox = dlsym(handle, "DB_ConnectOutbox");
-  if ((error = dlerror ()) != NULL)
+  if (g_module_symbol(handle, "DB_ConnectOutbox", (gpointer *)&DB_ConnectOutbox) == FALSE)
   {
-    g_print ("%s\n", error);
+    g_print ("Error getting symbol 'DB_ConnectOutbox': %s\n", g_module_error ());
     return (2);
   }
-  
-  DB_InsertSMS = dlsym(handle, "DB_InsertSMS");
-  if ((error = dlerror ()) != NULL)
+
+  if (g_module_symbol(handle, "DB_InsertSMS", (gpointer *)&DB_InsertSMS) == FALSE)
   {
-    g_print ("%s\n", error);
+    g_print ("Error getting symbol 'DB_InsertSMS': %s\n", g_module_error ());
     return (2);
   }
-  
-  DB_Look = dlsym(handle, "DB_Look");
-  if ((error = dlerror ()) != NULL)
+
+  if (g_module_symbol(handle, "DB_Look", (gpointer *)&DB_Look) == FALSE)
   {
-    g_print ("%s\n", error);
+    g_print ("Error getting symbol 'DB_Look': %s\n", g_module_error ());
     return (2);
   }
-  
+
   return (0);
 }
 
 
 static void Version (void)
 {
-  g_print ("\nsmsd - version 1.4-cvs		(20041011)\nCopyright  Jan Derfinak  <ja@mail.upjs.sk>\n");
+  g_print ("smsd - version %s from gnokii %s\nCopyright  Jan Derfinak  <ja@mail.upjs.sk>\n", SVERSION, VERSION);
 }
 
 
@@ -161,6 +157,7 @@ static void Usage (gchar *p)
              "            -t, --phone phone_number\n"
              "            -i, --interval polling_interval_for_incoming_sms's_in_seconds\n"
              "            -S, --maxsms number_of_sms's (only in dumb mode)\n"
+             "            -b, --inbox memoryType\n"
              "            -v, --version\n"
              "            -h, --help\n"), p);
 }
@@ -212,6 +209,7 @@ static void ReadConfig (gint argc, gchar *argv[])
   smsdConfig.phone = g_strdup ("");
   smsdConfig.refreshInt = 1;     // Phone querying interval in seconds
   smsdConfig.maxSMS = 10;        // Smsd uses it if GetSMSStatus isn't implemented
+  smsdConfig.firstSMS = -1;
   smsdConfig.smsSets = 0;
   smsdConfig.memoryType = GN_MT_XX;
 
@@ -398,19 +396,20 @@ GNOKII_API gint WriteSMS (gn_sms *sms)
   pthread_cond_wait (&sendSMSCond, &sendSMSMutex);
   pthread_mutex_unlock (&sendSMSMutex);
 
-  gn_log_xdebug ("Address: %s\nText: %s\n",
-  sms->remote.number,
-  sms->user_data[0].u.text);
+  gn_log_xdebug ("Address: %s\nText: %s\n", sms->remote.number, sms->user_data[0].u.text);
 
   error = m->status;
   g_free (m);
 
   if (smsdConfig.logFile)
   {
-    if (error)
-      LogFile (_("Sending to %s unsuccessful. Error %d\n"), sms->remote.number, error);
-    else
+    if (error) {
+      gn_log_xdebug("Sending to %s unsuccessful. Error: %s\n", sms->remote.number, gn_error_print(error));
+      LogFile (_("Sending to %s unsuccessful. Error %s\n"), sms->remote.number, gn_error_print(error));
+    } else {
+      gn_log_xdebug("Sending to %s successful.\n", sms->remote.number);
       LogFile (_("Sending to %s successful.\n"), sms->remote.number);
+    }
   }
 
   return (error);
@@ -422,50 +421,67 @@ static void ReadSMS(gpointer d, gpointer userData)
   gn_sms *data = (gn_sms *)d;
   PhoneEvent *e;
   gint error;
-  
+
   if (data->type == GN_SMS_MT_Deliver || data->type == GN_SMS_MT_DeliveryReport)
   {
-/*    if (data->type == GN_SMS_MT_DeliveryReport)
-    {
-      if (smsdConfig.smsSets & SMSD_READ_REPORTS)
-        error = (*DB_InsertSMS) (data);
-    }
-    else */
-    {  
-      gn_log_xdebug("%d. %s   ", data->number, data->remote.number);
-      gn_log_xdebug("%02d-%02d-%02d %02d:%02d:%02d+%02d %s\n", data->smsc_time.year,
-                     data->smsc_time.month, data->smsc_time.day, data->smsc_time.hour,
-                     data->smsc_time.minute, data->smsc_time.second, data->smsc_time.timezone,
-                     data->user_data[0].u.text);
-      error = (*DB_InsertSMS)(data, smsdConfig.phone);
-    }
+    gn_log_xdebug("%d. %s   ", data->number, data->remote.number);
+    gn_log_xdebug("%02d-%02d-%02d %02d:%02d:%02d+%02d %s\n", data->smsc_time.year,
+                   data->smsc_time.month, data->smsc_time.day, data->smsc_time.hour,
+                   data->smsc_time.minute, data->smsc_time.second, data->smsc_time.timezone,
+                   data->user_data[0].u.text);
+    error = (*DB_InsertSMS)(data, smsdConfig.phone);
 
-    switch (error) {
-    case SMSD_OK:
-      if (smsdConfig.logFile)
-        LogFile(_("Inserting sms from %s successful.\n"), data->remote.number);
-      e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent));
-      e->event = Event_DeleteSMSMessage;
-      e->data = data;
-      InsertEvent(e);
-      break;
-    case SMSD_DUPLICATE:
-      if (smsdConfig.logFile)
-        LogFile(_("Duplicated sms from %s.\n"), data->remote.number);
-      e = (PhoneEvent *) g_malloc (sizeof (PhoneEvent));
-      e->event = Event_DeleteSMSMessage;
-      e->data = data;
-      InsertEvent(e);
-      break;
-    default:
-      if (smsdConfig.logFile)
-        LogFile(_("Inserting sms from %s unsuccessful.\nDate: %02d-%02d-%02d %02d:%02d:%02d+%02d\nText: %s\n\nExiting."),
-                 data->remote.number, data->smsc_time.year,
-                 data->smsc_time.month, data->smsc_time.day,
-                 data->smsc_time.hour, data->smsc_time.minute,
-                 data->smsc_time.second, data->smsc_time.timezone,
-                 data->user_data[0].u.text);
-      break;
+    switch (error) 
+    {
+      case SMSD_OK:
+        if (smsdConfig.logFile) {
+          gn_log_xdebug("Inserting sms from %s successful.\n", data->remote.number);
+          LogFile(_("Inserting sms from %s successful.\n"), data->remote.number);
+        }
+        e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent));
+        e->event = Event_DeleteSMSMessage;
+        e->data = data;
+        InsertEvent(e);
+        break;
+        
+      case SMSD_DUPLICATE:
+        if (smsdConfig.logFile) {
+          gn_log_xdebug("Duplicated sms from %s.\n", data->remote.number);
+          LogFile(_("Duplicated sms from %s.\n"), data->remote.number);
+        }
+        e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent));
+        e->event = Event_DeleteSMSMessage;
+        e->data = data;
+        InsertEvent(e);
+        break;
+
+      case SMSD_WAITING:
+        if (smsdConfig.logFile) {
+          gn_log_xdebug("Multipart sms from %s. Waiting for the next parts.\n", data->remote.number);
+          LogFile(_("Multipart sms from %s. Waiting for the next parts.\n"), data->remote.number);
+        }
+        e = (PhoneEvent *) g_malloc(sizeof(PhoneEvent));
+        e->event = Event_DeleteSMSMessage;
+        e->data = data;
+        InsertEvent(e);
+        break;
+        
+      default:
+        if (smsdConfig.logFile) {
+          gn_log_xdebug("Inserting sms from %s unsuccessful.\nDate: %02d-%02d-%02d %02d:%02d:%02d+%02d\nText: %s\n\nExiting.\n",
+                  data->remote.number, data->smsc_time.year,
+                  data->smsc_time.month, data->smsc_time.day,
+                  data->smsc_time.hour, data->smsc_time.minute,
+                  data->smsc_time.second, data->smsc_time.timezone,
+                  data->user_data[0].u.text);
+          LogFile(_("Inserting sms from %s unsuccessful.\nDate: %02d-%02d-%02d %02d:%02d:%02d+%02d\nText: %s\n\nExiting.\n"),
+                  data->remote.number, data->smsc_time.year,
+                  data->smsc_time.month, data->smsc_time.day,
+                  data->smsc_time.hour, data->smsc_time.minute,
+                  data->smsc_time.second, data->smsc_time.timezone,
+                  data->user_data[0].u.text);
+        }
+        break;
     }
   }
 }
@@ -476,12 +492,13 @@ static void GetSMS (void)
   while (1)
   {
     pthread_mutex_lock (&smsMutex);
+    // Waiting for signal
     pthread_cond_wait (&smsCond, &smsMutex);
 
-    // Waiting for signal
-    pthread_mutex_unlock (&smsMutex);
     // Signal arrived.
-    
+    pthread_mutex_unlock (&smsMutex);
+
+    // Check if Mutex is free
     pthread_mutex_lock (&smsMutex);
     phoneMonitor.sms.messages = g_slist_reverse(phoneMonitor.sms.messages);
     g_slist_foreach (phoneMonitor.sms.messages, ReadSMS, (gpointer) NULL);
@@ -521,8 +538,9 @@ static void Run (void)
 int main (int argc, char *argv[])
 {
 #ifdef ENABLE_NLS
-  textdomain ("gnokii");
-  setlocale (LC_ALL, "");
+  setlocale(LC_ALL, "");
+  bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+  textdomain(GETTEXT_PACKAGE);
 #endif
 
   gn_elog_handler = NULL;
