@@ -1,6 +1,6 @@
 /*
 
-  $Id: config.h,v 1.4 2008/03/20 18:04:14 pkot Exp $
+  $Id: config.h,v 1.6 2008/05/30 19:34:54 pkot Exp $
 
   G N O K I I
 
@@ -24,7 +24,7 @@
 
   Copyright (C) 2003 Marcus Godehardt
 
-  This is the config.h file for GNOKII for MSVC6 compilers, you can
+  This is the config.h file for GNOKII for MSVS2008 compilers, you can
   edit this manually. This is not auto generated.
 
 */
@@ -35,14 +35,13 @@
 #if defined(_MSC_VER) && defined(WIN32)
 #	pragma once
 #else
-#	error This config.h is only for MSVC6 compiler !!!
+#	error This config.h is only for MSVS2008 compiler !!!
 #endif
 
-
 #undef VERSION
-#define VERSION "0.6.24"
+#define VERSION "0.6.26"
 
-/* We support Bluetooth and IRDA on MSVS 2005 */
+/* We support Bluetooth and IRDA on MSVS 2008 */
 #define HAVE_BLUETOOTH 1
 #define HAVE_IRDA 1
 
