@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_calendar.c,v 1.31 2006/08/15 10:57:20 dforsi Exp $
+  $Id: xgnokii_calendar.c,v 1.35 2008/02/14 12:54:06 dforsi Exp $
 
   X G N O K I I
 
@@ -22,13 +22,15 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999      Pavel Janik ml., Hugh Blemings
   Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2001-2002 Pawel Kot
   Copyright (C) 2002      BORBELY Zoltan, Markus Plail
 
 */
 
+#include "config.h"
+
 #include <time.h>
 #include <string.h>
 #include <gtk/gtk.h>
@@ -124,6 +126,12 @@ static AddDialogData addBirthdayDialogData;
 static CalendarDialog calendarDialog = { NULL, NULL };
 static CalTimeDialog calTimeDialog = { NULL, NULL };
 
+static void FunctionNotImplemented(void)
+{
+	gtk_label_set_text(GTK_LABEL(errorDialog.text), _("Function not implemented!"));  
+	gtk_widget_show(errorDialog.dialog);
+}
+
 static inline void Help1(GtkWidget * w, gpointer data)
 {
 	gchar *indx = g_strdup_printf("/help/%s/windows/calendar/index.html", xgnokiiConfig.help_locale);
@@ -506,6 +514,7 @@ static gint AddCalendarNote(gn_calnote * cnote)
 		g_free(buf);
 	} else {
 		gn_log_xdebug("Note saved\n");
+		ReadCalNotes();
 	}
 
 	return (error);
@@ -1404,6 +1413,10 @@ static void OkDeleteNoteDialog(GtkWidget * widget, gpointer data)
 		GUI_InsertEvent(e);
 	}
 
+	gtk_text_set_point(GTK_TEXT(cal.noteText), 0);
+	gtk_text_forward_delete(GTK_TEXT(cal.noteText),
+				gtk_text_get_length(GTK_TEXT(cal.noteText)));
+
 	gtk_widget_hide(GTK_WIDGET(data));
 
 	gtk_clist_thaw(GTK_CLIST(cal.notesClist));
@@ -1462,19 +1475,19 @@ static void DeleteNote(void)
 static GtkItemFactoryEntry menu_items[] = {
 	{NULL, NULL, NULL, 0, "<Branch>"},
 	{NULL, "<control>R", ReadCalNotes, 0, NULL},
-	{NULL, "<control>S", NULL, 0, NULL},
+	{NULL, "<control>S", FunctionNotImplemented, 0, NULL},
 	{NULL, NULL, NULL, 0, "<Separator>"},
-	{NULL, "<control>X", NULL, 0, NULL},
+	{NULL, "<control>X", FunctionNotImplemented, 0, NULL},
 	{NULL, NULL, NULL, 0, "<Separator>"},
-	{NULL, "<control>I", NULL, 0, NULL},
-	{NULL, "<control>E", NULL, 0, NULL},
+	{NULL, "<control>I", FunctionNotImplemented, 0, NULL},
+	{NULL, "<control>E", FunctionNotImplemented, 0, NULL},
 	{NULL, NULL, NULL, 0, "<Separator>"},
 	{NULL, "<control>W", CloseCalendar, 0, NULL},
 	{NULL, NULL, NULL, 0, "<Branch>"},
-	{NULL, "<control>N", NULL, 0, NULL},
-	{NULL, "<control>C", NULL, 0, NULL},
-	{NULL, "<control>M", NULL, 0, NULL},
-	{NULL, "<control>B", NULL, 0, NULL},
+	{NULL, "<control>N", AddReminder, 0, NULL},
+	{NULL, "<control>C", AddCall, 0, NULL},
+	{NULL, "<control>M", AddMeeting, 0, NULL},
+	{NULL, "<control>B", AddBirthday, 0, NULL},
 	/*
 	{NULL, NULL, NULL, 0, NULL},
 	*/
@@ -1488,30 +1501,30 @@ static GtkItemFactoryEntry menu_items[] = {
 
 static void InitMainMenu(void)
 {
-	menu_items[0].path = g_strdup(_("/_File"));
-	menu_items[1].path = g_strdup(_("/File/_Read from phone"));
-	menu_items[2].path = g_strdup(_("/File/_Save to phone"));
-	menu_items[3].path = g_strdup(_("/File/Sep1"));
-	menu_items[4].path = g_strdup(_("/File/Send via S_MS"));
-	menu_items[5].path = g_strdup(_("/File/Sep2"));
-	menu_items[6].path = g_strdup(_("/File/_Import from file"));
-	menu_items[7].path = g_strdup(_("/File/_Export to file"));
-	menu_items[8].path = g_strdup(_("/File/Sep3"));
-	menu_items[9].path = g_strdup(_("/File/_Close"));
-	menu_items[10].path = g_strdup(_("/_Edit"));
-	menu_items[11].path = g_strdup(_("/Edit/Add _reminder"));
-	menu_items[12].path = g_strdup(_("/Edit/Add _call"));
-	menu_items[13].path = g_strdup(_("/Edit/Add _meeting"));
-	menu_items[14].path = g_strdup(_("/Edit/Add _birthday"));
+	menu_items[0].path = _("/_File");
+	menu_items[1].path = _("/File/_Read from phone");
+	menu_items[2].path = _("/File/_Save to phone");
+	menu_items[3].path = _("/File/Sep1");
+	menu_items[4].path = _("/File/Send via S_MS");
+	menu_items[5].path = _("/File/Sep2");
+	menu_items[6].path = _("/File/_Import from file");
+	menu_items[7].path = _("/File/_Export to file");
+	menu_items[8].path = _("/File/Sep3");
+	menu_items[9].path = _("/File/_Close");
+	menu_items[10].path = _("/_Edit");
+	menu_items[11].path = _("/Edit/Add _reminder");
+	menu_items[12].path = _("/Edit/Add _call");
+	menu_items[13].path = _("/Edit/Add _meeting");
+	menu_items[14].path = _("/Edit/Add _birthday");
 	/*
-	menu_items[15].path = g_strdup(_("/Edit/_Edit"));
+	menu_items[15].path = _("/Edit/_Edit");
 	*/
-	menu_items[15].path = g_strdup(_("/Edit/_Delete"));
-	menu_items[16].path = g_strdup(_("/Edit/Sep4"));
-	menu_items[17].path = g_strdup(_("/Edit/Select _all"));
-	menu_items[18].path = g_strdup(_("/_Help"));
-	menu_items[19].path = g_strdup(_("/Help/_Help"));
-	menu_items[20].path = g_strdup(_("/Help/_About"));
+	menu_items[15].path = _("/Edit/_Delete");
+	menu_items[16].path = _("/Edit/Sep4");
+	menu_items[17].path = _("/Edit/Select _all");
+	menu_items[18].path = _("/_Help");
+	menu_items[19].path = _("/Help/_Help");
+	menu_items[20].path = _("/Help/_About");
 }
 
 void GUI_CreateCalendarWindow()
@@ -1576,25 +1589,25 @@ void GUI_CreateCalendarWindow()
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Save to phone"), NULL,
 				NewPixmap(Send_xpm, GUI_CalendarWindow->window,
 					  &GUI_CalendarWindow->style->bg[GTK_STATE_NORMAL]),
-				(GtkSignalFunc) NULL, NULL);
+				(GtkSignalFunc) FunctionNotImplemented, NULL);
 
 	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Send via SMS"), NULL,
 				NewPixmap(SendSMS_xpm, GUI_CalendarWindow->window,
 					  &GUI_CalendarWindow->style->bg[GTK_STATE_NORMAL]),
-				(GtkSignalFunc) NULL, NULL);
+				(GtkSignalFunc) FunctionNotImplemented, NULL);
 
 	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Import from file"), NULL,
 				NewPixmap(Open_xpm, GUI_CalendarWindow->window,
 					  &GUI_CalendarWindow->style->bg[GTK_STATE_NORMAL]),
-				(GtkSignalFunc) NULL, NULL);
+				(GtkSignalFunc) FunctionNotImplemented, NULL);
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Export to file"), NULL,
 				NewPixmap(Save_xpm, GUI_CalendarWindow->window,
 					  &GUI_CalendarWindow->style->bg[GTK_STATE_NORMAL]),
-				(GtkSignalFunc) NULL, NULL);
+				(GtkSignalFunc) FunctionNotImplemented, NULL);
 
 	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
 	/*
